Summary: Generic SPARC linux kernel
Name: kernel-sparc
%define version 2.0.30
Version: %{version}
Release: 2
Copyright: GPL
ExclusiveArch: sparc
Group: Base/Kernel
Provides: module-info
Source: vger.rutgers.edu:/pub/Linux/snapshots/sparclinux-2.0.30.tar.gz
Source1: kernel-config.sparc
Source2: module-info
Patch: kernel-make.patch
Patch1: kernel-smp.patch
Patch2: linux-2.0.30-freemem.patch
BuildRoot: /tmp/kernel

%package smp
Summary: SPARC linux kernel for multiprocessor machines
Group: Base/Kernel

%description smp
This package contains the Linux kernel that is used to boot and run
your system. It includes support for machines with multiple processors,
which will signicicantly improve performance on multiprocessor machines.
It will reduce performance on a single processor machine however. Most 
hardware is instead supported by modules loaded after booting.

%package -n kernel-source
Summary: Kernel source tree
Group: Base/Kernel
Requires: kernel-headers = %{version}

%package -n kernel-modules
Requires: kernel-sparc = %{version}
Summary: Collection of kernel modules
Group: Base/Kernel

%package -n kernel-headers
Summary: Header files for the Linux kernel.
Group: Base/Kernel
Provides: kernel-headers

%description -n kernel-headers
These are the C header files for the Linux kernel, which define structures
and constants that are needed when building most standard programs under
Linux, as well as to rebuild the kernel.

%description
This package contains the Linux kernel that is used to boot and run
your system. It contains few device drivers for specific hardware.
Most hardware is instead supported by modules loaded after booting.

%description -n kernel-source
This is the source code for the Linux kernel. It is required to build
most C programs as they depend on constants defined in here. You can
also build a custom kernel that is better tuned to your particular
hardware.

%description -n kernel-modules
This package includes the modules which provide the support for most
supported hardware devices.  The modules are loaded into the running
kernel after it is booted.

%prep
rm -rf $RPM_BUILD_ROOT
mkdir $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/usr/src/
cd $RPM_BUILD_ROOT/usr/src
zcat $RPM_SOURCE_DIR/sparclinux-2.0.30.tar.gz | tar -xf-
chown root.root -R linux

find linux -name "*.orig" -print | xargs rm -f
mv linux linux-%{version}
ln -sf linux-%{version} linux

cd linux-%{version}

cp $RPM_SOURCE_DIR/kernel-config.sparc arch/sparc/defconfig
%patch -p1 
%patch2 -p1 

# this is a bit silly, but we happen to have a dual processor sparc
# build machine so what the heck
if [ -f /proc/cpuinfo ]; then
    num=`awk -F: '/ncpus probed/ { print ($2 * 2) + 1; }' /proc/cpuinfo`
    mv Makefile Makefile.onecpu
    sed "s/^MAKE.*=make$/MAKE=make -j $num/" < Makefile.onecpu > Makefile
fi

%build
cd $RPM_BUILD_ROOT/usr/src/linux-%{version}
make oldconfig
make symlinks
make include/linux/version.h

rm -f /usr/include/linux 
ln -sf $RPM_BUILD_ROOT/usr/src/linux/include/linux /usr/include/linux
rm -f /usr/include/asm
ln -sf $RPM_BUILD_ROOT/usr/src/linux/include/asm /usr/include/asm

make vmlinux
make modules

rm -f /usr/include/linux 
ln -sf ../src/linux/include/linux /usr/include/linux
rm -f /usr/include/asm
ln -sf ../src/linux/include/asm /usr/include/asm

%install
cd $RPM_BUILD_ROOT/usr/src/linux-%{version}
mkdir $RPM_BUILD_ROOT/boot
install -m 644 $RPM_SOURCE_DIR/module-info $RPM_BUILD_ROOT/boot
install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-%{version}

strip vmlinux
gzip -9 vmlinux
cp vmlinux.gz $RPM_BUILD_ROOT/boot/vmlinux-%{version}.gz

make PREFIX=$RPM_BUILD_ROOT modules_install

rm -f vmlinux.gz

# now build the SMP flavor ;-)
cd $RPM_BUILD_ROOT/usr/src/linux-%{version}
patch -p1 < $RPM_SOURCE_DIR/kernel-smp.patch
make clean
make oldconfig
make boot

strip vmlinux
gzip -9 vmlinux
cp vmlinux.gz $RPM_BUILD_ROOT/boot/vmlinux-smp-%{version}.gz
install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-smp-%{version}

cd $RPM_BUILD_ROOT/usr/src/linux-%{version}

# keep kernel-source archive clean
make mrproper
make oldconfig
make symlinks
make include/linux/version.h

# make /usr/include/scsi link
mkdir -p ../../include
ln -s /usr/src/linux/include/scsi ../../include/scsi

%clean
rm -rf $RPM_BUILD_ROOT

%preun -n kernel-modules
if [ `uname -r` = "%{version}" ]; then 
	echo "You cannot remove the kernel-modules package for the currently "
	echo "running kernel".
	exit 1
fi

%post
ln -sf /boot/vmlinux-%{version}.gz /boot/vmlinux.gz
ln -sf /boot/System.map-%{version} /boot/System.map

%post -n kernel-headers
cd /usr/src
ln -snf linux-%{version} linux

%postun
if [ -L /usr/src/linux ]; then
    if [ `ls -l /usr/src/linux | awk '{ print $11 }'` = "linux-%{version}" ]; then
        rm -f /usr/src/linux
    fi
fi

%files
/boot/vmlinux-%{version}.gz
/boot/module-info
/boot/System.map-%{version}

%files smp
/boot/vmlinux-smp-%{version}.gz
/boot/module-info
/boot/System.map-smp-%{version}

%files -n kernel-source
%dir /usr/src/linux-%{version}
/usr/src/linux-%{version}/COPYING
/usr/src/linux-%{version}/CREDITS
/usr/src/linux-%{version}/Documentation
/usr/src/linux-%{version}/MAINTAINERS
/usr/src/linux-%{version}/Makefile
/usr/src/linux-%{version}/Makefile.orig
/usr/src/linux-%{version}/README
/usr/src/linux-%{version}/Rules.make
/usr/src/linux-%{version}/arch
/usr/src/linux-%{version}/drivers
/usr/src/linux-%{version}/fs
/usr/src/linux-%{version}/init
/usr/src/linux-%{version}/ipc
/usr/src/linux-%{version}/kernel
/usr/src/linux-%{version}/lib
/usr/src/linux-%{version}/mm
/usr/src/linux-%{version}/modules
/usr/src/linux-%{version}/net
/usr/src/linux-%{version}/scripts

%files -n kernel-headers
/usr/src/linux-%{version}/include/asm
/usr/src/linux-%{version}/include/asm-generic
/usr/src/linux-%{version}/include/asm-sparc
/usr/src/linux-%{version}/include/linux
/usr/src/linux-%{version}/include/net
/usr/src/linux-%{version}/include/scsi
/usr/include/scsi

%files -n kernel-modules
%dir /lib/modules
%dir /lib/modules/%{version}
/lib/modules/%{version}/net
/lib/modules/%{version}/block
/lib/modules/%{version}/fs
/lib/modules/%{version}/misc
/lib/modules/%{version}/ipv4

